import React, { useState, useEffect } from 'react';
import PropTypes from 'prop-types';

var styles = {"dataTable":"_3E0q0","asc":"_8wNzl","desc":"_1Lsrq","sort-col-0":"_j0YGU","sort-col-1":"_3YLHu","sort-col-2":"_24LAI"};

var locSort = function locSort(a, b, col) {
  var ret;
  switch (col.type) {
    default:
    case 'string':
      ret = a[col.col].localeCompare(b[col.col]);
      break;
    case 'date':
      ret = new Date(a[col.col]) < new Date(b[col.col]) ? -1 : 1;
      break;
  }
  return col.sens === 'asc' ? ret : -ret;
};
locSort.propTypes = {
  a: PropTypes.object,
  b: PropTypes.object,
  col: PropTypes.shape({
    col: PropTypes.string,
    sens: PropTypes.string
  })
};
var sortData = function sortData(col1, col2, col3, a, b) {
  var returnResult;
  if (col1.col && a[col1.col] === b[col1.col]) {
    if (col2.col && a[col2.col] === b[col2.col]) {
      if (col3.col) {
        returnResult = locSort(a, b, col3);
      } else {
        returnResult = 0;
      }
    } else {
      if (col2.col) {
        returnResult = locSort(a, b, col2);
      } else {
        returnResult = 0;
      }
    }
  } else {
    if (col1.col) {
      returnResult = locSort(a, b, col1);
    } else {
      returnResult = 0;
    }
  }
  return returnResult;
};
sortData.propTypes = {
  col1: PropTypes.shape({
    col: PropTypes.string,
    sens: PropTypes.string
  }),
  col2: PropTypes.shape({
    col: PropTypes.string,
    sens: PropTypes.string
  }),
  col3: PropTypes.shape({
    col: PropTypes.string,
    sens: PropTypes.string
  }),
  a: PropTypes.any,
  b: PropTypes.any
};
var DataTable = function DataTable(_ref) {
  var formatCols = _ref.formatCols,
    data = _ref.data,
    curPage = _ref.curPage,
    nbPerPage = _ref.nbPerPage;
  var indexStart = curPage * nbPerPage;
  var indexEnd = curPage * nbPerPage + nbPerPage;
  var colCount = formatCols.length;
  var _useState = useState([{
      col: null,
      type: null,
      sens: 'asc'
    }, {
      col: null,
      type: null,
      sens: 'asc'
    }, {
      col: null,
      type: null,
      sens: 'asc'
    }]),
    sortColumn = _useState[0],
    setSortColumn = _useState[1];
  var _useState2 = useState(0),
    sortIndex = _useState2[0],
    setSortIndex = _useState2[1];
  var _useState3 = useState(data),
    dataSorted = _useState3[0],
    setDataSorted = _useState3[1];
  var inverSortOrderOfCurrentColumn = function inverSortOrderOfCurrentColumn(column) {
    var temp = [].concat(sortColumn);
    temp[column].sens = temp[column].sens === 'asc' ? 'desc' : 'asc';
    setSortColumn(temp);
  };
  var resetSortColumns = function resetSortColumns(colName, type) {
    var temp = [].concat(sortColumn);
    temp = [{
      col: colName,
      type: type,
      sens: 'asc'
    }, {
      col: null,
      type: null,
      sens: 'asc'
    }, {
      col: null,
      type: null,
      sens: 'asc'
    }];
    setSortIndex(0);
    setSortColumn(temp);
  };
  var addSortColumn = function addSortColumn(a, shift) {
    var temp = [].concat(sortColumn);
    var type = searchFormat(a).type;
    if (shift && sortIndex === 2 || temp[0].col === null || !shift) {
      resetSortColumns(a, type);
    } else {
      temp[sortIndex + 1] = {
        col: a,
        type: type,
        sens: 'asc'
      };
      setSortIndex(sortIndex + 1);
      setSortColumn(temp);
    }
  };
  var searchColumn = function searchColumn(a) {
    for (var i = 0; i < sortColumn.length; i++) {
      if (sortColumn[i].col === a) {
        return i;
      }
    }
    return -1;
  };
  var searchFormat = function searchFormat(colName) {
    for (var i = 0; i < formatCols.length; i++) {
      if (formatCols[i].data === colName) {
        return formatCols[i];
      }
    }
    return -1;
  };
  var changeSortOrder = function changeSortOrder(e) {
    e.preventDefault();
    document.getSelection().removeAllRanges();
    var a = e.currentTarget.attributes.getNamedItem('data-name');
    if (a) {
      var idx = searchColumn(a.value);
      if (idx !== -1 && a.value === sortColumn[idx].col) {
        inverSortOrderOfCurrentColumn(idx);
      } else {
        addSortColumn(a.value, e.shiftKey);
      }
    }
  };
  var display = function display(type, data) {
    switch (type) {
      case 'string':
        return data;
      case 'date':
        return new Date(data).toLocaleDateString('fr');
      default:
        return data;
    }
  };
  useEffect(function () {
    var orig = [].concat(data);
    setDataSorted(orig.sort(function (a, b) {
      return sortData(sortColumn[0], sortColumn[1], sortColumn[2], a, b);
    }));
  }, [sortColumn, data]);
  return /*#__PURE__*/React.createElement("table", {
    className: styles.dataTable,
    role: "grid"
  }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", null, formatCols.map(function (element, index) {
    var cl = sortColumn.map(function (col, idx) {
      return col.col === element.data ? styles[col.sens] + ' ' + styles['sort-col-' + idx] : '';
    });
    return /*#__PURE__*/React.createElement("th", {
      key: 'th-table-key-' + index,
      "data-name": element.data,
      className: cl.join(' ').trim(),
      onClick: changeSortOrder
    }, element.title);
  }))), /*#__PURE__*/React.createElement("tbody", null, dataSorted.length ? dataSorted.map(function (ligne, iLigne) {
    return iLigne >= indexStart && iLigne < indexEnd ? /*#__PURE__*/React.createElement("tr", {
      className: styles.tbodyTr,
      key: 'tr-table-key-' + iLigne
    }, formatCols.map(function (element, index) {
      var cl = sortColumn.map(function (col, idx) {
        return col.col === element.data ? styles[col.sens] + ' ' + styles['sort-col-' + idx] : '';
      });
      return /*#__PURE__*/React.createElement("td", {
        key: 'td-table-key-' + index,
        className: cl.join(' ').trim()
      }, display(element.type, ligne[element.data]));
    })) : null;
  }) : /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", {
    colSpan: colCount
  }, "No matching record found"))));
};
DataTable.propTypes = {
  formatCols: PropTypes.arrayOf(PropTypes.shape({
    type: PropTypes.string,
    title: PropTypes.string,
    data: PropTypes.string
  })),
  data: PropTypes.arrayOf(PropTypes.object),
  curPage: PropTypes.number,
  nbPerPage: PropTypes.number
};

export { DataTable };
//# sourceMappingURL=index.modern.js.map
